package BookShelf::View::TT;

use strict;
use base qw/ Catalyst::View::TT::ControllerLocal Catalyst::Enzyme::CRUD::View /;

=head1 NAME

BookShelf::View::TT - Catalyst Catalyst::Enzyme::CRUD::View TT View




=head1 SYNOPSIS

See L<BookShelf>



=head1 DESCRIPTION

Catalyst TT View with L<Catalyst::View::TT::ControllerLocal> and
L<Catalyst::Enzyme::CRUD::View> CRUD support.



=head1 AUTHOR

A clever guy



=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
